
import os
from io import BytesIO
from shutil import copyfile

import magic
from PIL import Image


def upload_thumbnail(image_data: bytes, filename: str, size: int = 300) -> bool:
    # Only process the image, if its size is more than zero.  Zero size means no new image was uploaded
    if image_data is None or len(image_data) == 0:
        return False
    # Detect the MIME type
    filemagic: magic.FileMagic = magic.detect_from_content(image_data)
    if not filemagic.mime_type.startswith('image/'):
        raise ValueError(f'Unsupported file type: {filemagic.mime_type}')
    # Create the absolute path of the upload directory
    dirname: str = os.path.abspath(os.path.dirname(filename))
    os.makedirs(dirname, exist_ok=True)

    # Parse the image data
    try:
        image: Image = Image.open(BytesIO(image_data))
    except IOError:
        raise ValueError(f'Unsupported file type: {filemagic.mime_type}')
    # Resize the image preserving the aspect ratio
    if image.width > image.height:
        resized = image.resize((size, size*image.height//image.width), Image.LANCZOS)
    else:
        resized = image.resize((size*image.width//image.height, size), Image.LANCZOS)

    # Create a new square transparent image and paste the thumbnail in the center
    thumb: Image = Image.new('RGBA', (size, size), (0, 0, 0, 0))
    x = (thumb.width - resized.width) // 2
    y = (thumb.height - resized.height) // 2
    thumb.paste(resized, (x, y))
    # Write the image to the file
    thumb.save(filename, 'PNG')
    return True
